package com.mysoftkey.jaxrs;

import java.util.List;

import javax.ws.rs.DefaultValue;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;

/**
 * This Service class is used to demonstrate to get values from queryString with different approach.
 * 
 * @author Ranjeet Jha
 *
 */
@Path("/queryParam")
public class JerseryQueryParamService {

	/**
	 * In this method , retrieve few parameters from queryString.
	 * 
	 * service end point:  http://localhost:8080/jersey/queryParam/withQuery?offset=1&len=10&orderBy=firstName&orderBy=lastName
	 * @param from
	 * @param to
	 * @param orderBy
	 * @return
	 */
	@GET
	@Path("/withQuery")
	public Response getParamsFromQueryString(@QueryParam("offset") int from,
			@QueryParam("len") int to, @QueryParam("orderBy") List<String> orderBy) {

		return Response.status(200).entity(" offset : " + from + ", len : " + to
						+ ", orderBy" + orderBy.toString()).build();

	}
	
	/**
	 * In this method , retrieve multiple parameters from {@link UriInfo} for queryString.
	 * 
	 * Service end point : http://localhost:8080/jersey/queryParam/withUriInfo?offset=1&len=10&orderBy=firstName&orderBy=lastName
	 * 
	 * @param info
	 * @return
	 */
	@GET
	@Path("/withUriInfo")
	public Response getPersonInfo(@Context UriInfo info) {
		String offset = info.getQueryParameters().getFirst("offset");
		String len = info.getQueryParameters().getFirst("len");
		List<String> orderBy = info.getQueryParameters().get("orderBy");
		
		return Response.status(200).entity("offset: " + offset + ", length : " + len + ", orderBy"
					+ orderBy.toString()).build();

	}
	
	/**
	 * In this method , retrieve multiple parameters from queryParam with default value, 
	 * it means if parameter is not available in queryString it takes default value assigned to. 
	 * in the following url , offset we are not providing then it pick default value i.e. 1.
	 * 
	 * Service URL: http://localhost:8080/jersey/queryParam/withDefaultValue?len=10&orderBy=firstName&orderBy=lastName
	 *   
	 * @param offset
	 * @param length
	 * @param orderBy
	 * @return
	 */
	@GET
	@Path("/withDefaultValue")
	public Response getQueryParamWithDefaultVale(
			@DefaultValue("1") @QueryParam("offset") int offset,
			@DefaultValue("10") @QueryParam("len") int length,
			@DefaultValue("name") @QueryParam("orderBy") List<String> orderBy) {

		return Response.status(200).entity("offset : " + offset + ", length : " + length
						+ ", orderBy" + orderBy.toString()).build();

	}
}
